reset property
A flag to reset analyticsContext. Default is false.
If set to true, a new analytics context will be created.
If set to false, it will merge with the existing analytics context.
Implementation
final bool reset;
A flag to reset analyticsContext. Default is false.
If set to true, a new analytics context will be created.
If set to false, it will merge with the existing analytics context.
final bool reset;