startupSequence property

StartupSequence? startupSequence
final

Access to the StartupSequence system. If the app is rendering widgets using the StandardAppPlugin system, StartupSequence.resetMachine is automatically executed only once when the app is launched.

Implementation

final StartupSequence? startupSequence;