ErrorEnvironment mixin
Settings for PatapataException
Properties
-
errorDefaultShowDialog
→ Future<
void> Function(BuildContext, PatapataException)? -
Defines the default behavior of PatapataException.showDialog.
no setter
- errorDefaultWidget → Widget Function(PatapataException)?
-
Defines the default PatapataException.widget.
no setter
-
errorReplacePrefixMap
→ Map<
String, String> ? -
Overrides the value of PatapataException.prefix by PatapataException.namespace.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited