requireRemoteConfig property

  1. @override
bool requireRemoteConfig
final

This property determines whether initialization should occur after the RemoteConfig system has started when set to true, or before it starts when set to false.

Implementation

@override
final bool requireRemoteConfig;