LogicStateError class

The state in which LogicStateMachine terminated with an error.

Inheritance

Constructors

LogicStateError(Object error, StackTrace? stackTrace)

Properties

backAllowed bool
If true, allows going back via backByType. (default is false)
getter/setter pairinherited
error Object
Error details.
final
hashCode int
The hash code for this object.
no setterinherited
onComplete Future<void>
Returns a Future that waits until the state is complete.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
StackTrace
final

Methods

backByType(Type stateType, [Object? data]) → void
Goes back to a state that has already been executed, regardless of the value of its own LogicStateTransition.
inherited
call() bool
Returns true if LogicStateMachine.current is itself.
inherited
complete() → void
Completes the state and transitions to the next LogicState.
inherited
completeError(Object error, [StackTrace? stackTrace]) → void
Completes the state with an error. It will not transition to the next LogicState, and the LogicStateMachine will terminate as an error.
inherited
dispose() → void
Called when the state processing is completed.
inherited
init(Object? data) → void
Executed first when the state is created.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to<T extends LogicState>([Object? data]) → void
Transitions to the state of type T.
inherited
toByType(Type stateType, [Object? data]) → void
Transitions to the state of stateType.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited