message property
Error message. This message is for logging and debugging purposes and is not meant to be displayed to the user.
Implementation
final String? message;
Error message. This message is for logging and debugging purposes and is not meant to be displayed to the user.
final String? message;