Plugin.inline constructor

Plugin.inline({
  1. String name = 'inline',
  2. List<Type> dependencies = const [],
  3. bool requireRemoteConfig = false,
  4. FutureOr<bool> init(
    1. App<Object> app
    )?,
  5. FutureOr<void> dispose()?,
  6. Widget createAppWidgetWrapper(
    1. Widget child
    )?,
  7. RemoteConfig? createRemoteConfig()?,
  8. LocalConfig? createLocalConfig()?,
  9. RemoteMessaging? createRemoteMessaging()?,
  10. List<NavigatorObserver> navigatorObservers()?,
})

Create a Plugin that can be used in App. If you want to implement a Plugin that you can pass directly to App.plugins, you can use this constructor without having to create your own class.

Implementation

factory Plugin.inline({
  String name = 'inline',
  List<Type> dependencies = const [],
  bool requireRemoteConfig = false,
  FutureOr<bool> Function(App app)? init,
  FutureOr<void> Function()? dispose,
  Widget Function(Widget child)? createAppWidgetWrapper,
  RemoteConfig? Function()? createRemoteConfig,
  LocalConfig? Function()? createLocalConfig,
  RemoteMessaging? Function()? createRemoteMessaging,
  List<NavigatorObserver> Function()? navigatorObservers,
}) => InlinePlugin(
  name: name,
  dependencies: dependencies,
  requireRemoteConfig: requireRemoteConfig,
  init: init,
  dispose: dispose,
  createAppWidgetWrapper: createAppWidgetWrapper,
  createRemoteConfig: createRemoteConfig,
  createLocalConfig: createLocalConfig,
  createRemoteMessaging: createRemoteMessaging,
  navigatorObservers: navigatorObservers,
);