complete property
bool
get
complete
Whether the sequence has completed, successfully or due to an error.
Implementation
bool get complete => _startupCompleted;
Whether the sequence has completed, successfully or due to an error.
bool get complete => _startupCompleted;