error property
LogicStateError?
get
error
The details of the error that occurred during execution.
Implementation
LogicStateError? get error => _error;
The details of the error that occurred during execution.
LogicStateError? get error => _error;