StartupStateFactory<T extends StartupState> class

A factory for states used in the StartupSequence system.

Constructors

StartupStateFactory(T create(StartupSequence startupSequence), List<LogicStateTransition<StartupState>> transitions)
const

Properties

create → T Function(StartupSequence startupSequence)
Creates a StartupState. startupSequence is the StartupSequence that generated this state.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited