addSynchronousChangeListener method
Adds a listener to monitor updates to user data.
When user-related data is updating, the callback is invoked,
and the changed value is set to changes.
The content of changes can be modified within the callback.
Once all the listener's callbacks have successfully completed,
the final values in changes are committed.
If any listener returns an error, the changes are discarded.
Implementation
void addSynchronousChangeListener(
FutureOr<void> Function(User user, UserChangeData changes) callback,
) => _synchronousChangeListeners.add(callback);