getData<T extends Object?> method
Retrieves arbitrary data.
This value can be used for data exchange within the application and is not intended to be sent to external packages.
Implementation
Future<T?> getData<T extends Object?>(String key) async {
final tData = await _data.getValue();
return tData[key] as T?;
}