properties property
The user properties.
This value can be shared outside of the application (such as in external packages). (e.g., Analytics or Sentry)
By using getPropertiesFor, you can obtain values overridden for each Type.
The value obtained may not be the latest.
Implementation
Map<String, Object?> get properties => Map.from(_properties.unsafeValue);