getApp<T extends Object> function

App<T> getApp<T extends Object>()

Returns the App for the current Zone. In almost all cases in your application, you can use this to grab your App instance without a BuildContext T is not required and will work undefined (as dynamic).

Implementation

App<T> getApp<T extends Object>() =>
    ((kDebugMode && !kIsTest)
            ? (Zone.current[#patapataApp] ?? // coverage:ignore-line
                  _debugAppZone[#patapataApp]) // coverage:ignore-line
            : Zone.current[#patapataApp])
        as App<T>;