PlatformDialogAction<T> class

The set of actions that are displayed at the bottom of the dialog.

On iOS, CupertinoDialogAction is used, and on other platforms, TextButton is used.

Constructors

PlatformDialogAction({required T result(), VoidCallback? action, bool isDestructive = false, bool isDefault = false, String? text, Widget? child})
const

Properties

action → VoidCallback?
The callback that is called when the button is tapped or otherwise activated.
final
child → Widget?
Widget to display as a button.
final
hashCode → int
The hash code for this object.
no setterinherited
isDefault → bool
Set to true if button is the default choice in the dialog.
final
isDestructive → bool
Whether this action destroys an object.
final
result → T Function()
The callback that is called when the button is tapped or otherwise activated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Text to display on the button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited