LogicState class abstract
The state to be executed in LogicStateMachine.
- Implementers
Constructors
Properties
- backAllowed ↔ bool
-
If true, allows going back via backByType. (default is false)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onComplete
→ Future<
void> -
Returns a Future that waits until the state is complete.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
backByType(
Type stateType, [Object? data]) → void - Goes back to a state that has already been executed, regardless of the value of its own LogicStateTransition.
-
call(
) → bool - Returns true if LogicStateMachine.current is itself.
-
complete(
) → void - Completes the state and transitions to the next LogicState.
-
completeError(
Object error, [StackTrace? stackTrace]) → void - Completes the state with an error. It will not transition to the next LogicState, and the LogicStateMachine will terminate as an error.
-
dispose(
) → void - Called when the state processing is completed.
-
init(
Object? data) → void - Executed first when the state is created.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
to<
T extends LogicState> ([Object? data]) → void -
Transitions to the state of type
T. -
toByType(
Type stateType, [Object? data]) → void -
Transitions to the state of
stateType. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited