localizedTitle property
String
get
localizedTitle
Displays the error title localized by the L10n system.
The localization key will be 'errors.$namespace.$internalCode.title'.
example: namespace is patapata and internalCode is 000, then
errors:
patapata:
'000':
title: ErrorTitle
If StandardPageWithResult.localizationKey is set on the currently displayed page when this class is created,
you can override the default keys and display page-specific title by creating the following YAML file.
However, if overridableLocalization was set to false when created, the keys will not be overridden.
Example: If StandardPageWithResult.localizationKey is pages.home, then
pages:
home:
errors:
patapata:
'000':
title: Will be displayed
errors:
patapata:
'000':
title: Will not be displayed
Implementation
String get localizedTitle => hasLocalizedTitle
? _localize(_localizeTitleKey, localeTitleData)
: _defaultTitle;