goWithResult method
Navigate to the StandardPage of type T with the option to pass pageData during navigation.
An optional navigationMode representing the mode of StandardPageNavigationMode to use during navigation can also be provided.
pushParentPage indicates whether to push the parent page when navigating to a child page. default is false.
Implementation
Future<E?> goWithResult(
R pageData, [
StandardPageNavigationMode? navigationMode,
bool pushParentPage = false,
]) =>
_delegate.goWithResult<T, R, E>(pageData, navigationMode, pushParentPage);